@@ -31,3 +31,11 @@ test_that("list_kafka_versions", {
 test_that("list_kafka_versions", {
   expect_error(svc$list_kafka_versions(MaxResults = 20), NA)
 })
+
+test_that("list_vpc_connections", {
+  expect_error(svc$list_vpc_connections(), NA)
+})
+
+test_that("list_vpc_connections", {
+  expect_error(svc$list_vpc_connections(MaxResults = 20), NA)
+})
